@@ -6,7 +6,7 @@ scan a music directory to find concerts near a specified location
 
 from .version import __version__
 from .cli import parse_args
-from .scan import scan_dir
+from .scan import scan_wrapper
 from .concerts import bit
 from .output import output_wrapper
 
@@ -14,7 +14,7 @@ from .output import output_wrapper
 def main():
     """Main function."""
     args = parse_args()
-    raw_artists = scan_dir(args.directory, args.cache)
+    raw_artists = scan_wrapper(args.directory, args.cache)
     concerts_list = bit(raw_artists, args)
     output_wrapper(concerts_list, args.output)
 
